sample_test_fail_first_setup_20150203_185527

### sample_config2

Total tests | Passed | Failed | Skipped | Start time | End time | Execution time | Naarad
--- | --- | --- | --- | --- | --- | --- | ---
3 | 2 | 0 | 1 | 2015-02-03 18:56:09 | 2015-02-03 18:56:09 | 0.157665014267 sec | Report

###

Test Name | Result | Description
--- | --- | ---
test1 | Skipped | Test has no docstring :(
test0 | Passed | Test has no docstring :(
test2 | Passed | Test has no docstring :(

###

Config Key | Value
--- | ---
a | b
c | d
max_failures_per_suite_before_abort | -1